## ----opts, echo=FALSE, results="hide"-------------------------------------------------
knitr::opts_chunk$set(fig.width=8, fig.height=5)
options(width = 88)

## ----mycss, results="asis", echo=FALSE------------------------------------------------
cat('
<style type="text/css">
.figure { text-align: center; }
.caption { font-weight: bold; }
</style>
')

## ----Setup----------------------------------------------------------------------------
library(SVAlignR)
data(longreads)
head(longreads[, 1:3])

## ----LR-------------------------------------------------------------------------------
LR0 <- longreads$connection
names(LR0) <- rownames(longreads)
LR <- LR0[!duplicated(LR0)]
weights <- sapply(LR, function(lr) sum(LR0 == lr))
length(LR) # expect 158

## ----unique.symbols-------------------------------------------------------------------
alphabet <- Cipher(LR)
alphabet

## ----pseudo---------------------------------------------------------------------------
head(LR)
pseudo <- encode(alphabet, LR)
head(pseudo)

## ----compute.distances----------------------------------------------------------------
seqclust <- SequenceCluster(LR0, NC = 15)
table(seqclust@clusters)

## ----fig01, fig.cap = "Figure 1: Hierarchical clustering of break point sequences.", fig.width = 12----
plot(seqclust)

## ----fig02, fig.width=8, fig.cap = "Figure 2: Uncluttered clusters."------------------
plot(seqclust, type = "clipped")

## ----fig03, fig.cap = "Figure 3: Unrooted phylogeny tree.", fig.width=9, fig.height=9----
plot(seqclust, type = "unrooted")

## ----fig04, fig.cap = "Figure 4: Heatmap of the distance matrix.", fig.width=9, fig.height=9----
heat(seqclust)

## ----do.align-------------------------------------------------------------------------
MYSUB <- makeSubsMatrix(match = 2, mismatch = -6)
consensus <- alignAllClusters(seqclust, mysub = MYSUB, gapO = 2, gapE = 0.1)
class(consensus)
length(consensus)

## ----fig05 , fig.cap="Figure 5: Example alignment of cluster 15."---------------------
opar <- par(mai = c(1.02, 0.82, 0.82, 0.82))
image(consensus[[15]])
par(opar)
rm(opar)

## ----fig06, fig.cap="Figure 6: Multiple sequence alignments of clusters.", fig.width=20, fig.height=20----
opar <- par(mfrow = c(4,3))
for (K in 1:length(consensus)) {
  image(consensus[[K]], col = SVAlignR:::myColorSet[K])
}
par(opar)

## ----conseq, fig.cap="Alignment of all consensus sequences.", echo=FALSE, eval = FALSE----
# allmodcons <- sapply(consensus, function(X) X@consensus)
# allmodcons <- gsub("\\?", "q", allmodcons) # make question mark a letter
# allmodcons <- gsub("\\:", "z", allmodcons) # make rare colon a letter
# while (length(grep("^[qz]", allmodcons) > 0)) {
#   allmodcons <- sub("^q-", "", allmodcons)
#   allmodcons <- sub("^z-", "", allmodcons)
# }
# while (length(grep("[qz]$", allmodcons) > 0)) {
#   allmodcons <- sub("-q$", "", allmodcons)
#   allmodcons <- sub("-z$", "", allmodcons)
# }
# names(allmodcons) <- paste("C", c(rep(0,9), rep("", 11)), 1:20, sep = "")
# 
# newsub <- makeSubsMatrix(match = 2, mismatch = -6)
# ab <- alignCluster(allmodcons, mysub = newsub, gapO = 0.1, gapE = 0.2)
# image(ab)
# 

## ----fig07, fig.cap = "Figure 7: Unrooted phylogeny tree with consensus sequences.", fig.width=9, fig.height=9----
library(dendextend)
myColorSet <- SVAlignR:::myColorSet
NC <- seqclust@NC
mycut <- mean(rev(seqclust@hc$height)[NC + -1:0])
hcd <- as.dendrogram(seqclust@hc)
dend2 <- cut(hcd, h = mycut)
DU <- dend2$upper
blocks <- sapply(consensus, function(X) {
  X@consensus
})
labels(DU) <- paste("   [", 1:NC, "]  ",  blocks, "   ", sep = "")

opar <- par(bg = "gray90")
plot(ape::as.phylo(DU), type = "unrooted", rotate.tree = -20,
     edge.color = "black", edge.width = 2,
     lab4ut = "axial", 
     tip.color = myColorSet[1:NC], cex = 1.2)
par(opar)


## ----makepngs, eval = FALSE, echo=FALSE, results = "hide"-----------------------------
# resn <- 300
# for (K in 1:NK) {
#   temp <- consensus[[K]]
#   png(file = file.path(paths$figs, paste("cons-", K, ".png", sep = "")),
#       width = 6*resn, height = 4*resn, res = resn, bg = "white")
#   showme(temp, col = SVAlignR:::myColorSet[K], cex = 0.5)
#   dev.off()
# }

## ----deBruijn-------------------------------------------------------------------------
library("igraph")
DB <- deBruijn(seqclust@rawSequences, 4)
G <- DB@G
loci <- layout_with_fr(G)
plot(G, layout = loci)


count_components(G)
comp <- components(G)
sort(comp$csize)

GC <- largest_component(G)
gloc <- layout_with_gem(GC)
plot(GC, layout = gloc)

sort(table(E(GC)$weight))
GE <- delete_edges(GC, E(GC)[E(GC)$weight  < 6])
GE <- largest_component(GE)
#GE <- set_edge_attr(GE, "width", value = sqrt(edge_attr(G, "weight")))
gloc <- layout_with_fr(GE)
plot(GE, layout = gloc)

## ----debruijn sets--------------------------------------------------------------------
dbset <- lapply(1:seqclust@NC, function(J) {
  rs <- seqclust@rawSequences[seqclust@clusters == J]
  db <- deBruijn(rs, 4)
}) 
L <- length(dbset)
for (I in 1:L) {
  G <- dbset[[I]]@G
  lyt <- layout_with_fr(G)
  plot(G, layout =lyt, main = paste("Cluster", I))
}


## ----si-------------------------------------------------------------------------------
sessionInfo()

